@@ -30,9 +30,19 @@ NAME_TYPE_SUBNET = 'subnet'
 NAME_TYPE_PORT = 'port'
 NAME_TYPE_ROUTER = 'router'
 NAME_TYPE_APP_PROFILE = 'app-profile'
+NAME_TYPE_POLICY_TARGET_GROUP = 'policy_target_group'
+NAME_TYPE_L3_POLICY = 'l3_policy'
+NAME_TYPE_L2_POLICY = 'l2_policy'
+NAME_TYPE_POLICY_RULE_SET = 'policy_rule_set'
+NAME_TYPE_POLICY_RULE = 'policy_rule'
+NAME_TYPE_EXTERNAL_SEGMENT = 'external_segment'
+NAME_TYPE_EXTERNAL_POLICY = 'external_policy'
+NAME_TYPE_NAT_POOL = 'nat_pool'
+
 
 MAX_APIC_NAME_LENGTH = 46
 
+
 @contextlib.contextmanager
 def mapper_context(context):
     if context and (not hasattr(context, '_plugin_context') or
@@ -150,6 +160,54 @@ class APICNameMapper(object):
             'SELECT * from routers WHERE id = :id',
             {'id': router_id}).fetchone().name
 
+    @mapper(NAME_TYPE_POLICY_TARGET_GROUP)
+    def policy_target_group(self, context, policy_target_group_id):
+        epg = context._plugin.get_policy_target_group(context._plugin_context,
+                                                 policy_target_group_id)
+        return epg['name']
+
+    @mapper(NAME_TYPE_L3_POLICY)
+    def l3_policy(self, context, l3_policy_id):
+        l3_policy = context._plugin.get_l3_policy(context._plugin_context,
+                                                  l3_policy_id)
+        return l3_policy['name']
+
+    @mapper(NAME_TYPE_L3_POLICY)
+    def l2_policy(self, context, l2_policy_id):
+        l2_policy = context._plugin.get_l2_policy(context._plugin_context,
+                                                  l2_policy_id)
+        return l2_policy['name']
+
+    @mapper(NAME_TYPE_POLICY_RULE_SET)
+    def policy_rule_set(self, context, policy_rule_set_id):
+        policy_rule_set = context._plugin.get_policy_rule_set(
+            context._plugin_context, policy_rule_set_id)
+        return policy_rule_set['name']
+
+    @mapper(NAME_TYPE_POLICY_RULE)
+    def policy_rule(self, context, policy_rule_id):
+        policy_rule = context._plugin.get_policy_rule(context._plugin_context,
+                                                      policy_rule_id)
+        return policy_rule['name']
+
+    @mapper(NAME_TYPE_EXTERNAL_SEGMENT)
+    def external_segment(self, context, external_segment_id):
+        external_segment = context._plugin.get_external_segment(
+            context._plugin_context, external_segment_id)
+        return external_segment['name']
+
+    @mapper(NAME_TYPE_EXTERNAL_POLICY)
+    def external_policy(self, context, external_policy_id):
+        external_policy = context._plugin.get_external_policy(
+            context._plugin_context,  external_policy_id)
+        return external_policy['name']
+
+    @mapper(NAME_TYPE_NAT_POOL)
+    def nat_pool(self, context, nat_pool_id):
+        nat_pool = context._plugin.get_nat_pool(context._plugin_context,
+                                                nat_pool_id)
+        return nat_pool['name']
+
     def app_profile(self, context, app_profile, remap=False):
         if remap:
             self.db.delete_apic_name('app_profile')
